import { Box, Tab } from "@mui/material";
import {TabContext, TabList, TabPanel} from '@mui/lab';
import Collapsible from "../components/Collapsible"; 
import { useEffect } from "react";
import { useLocation } from "react-router-dom";
import { openFromOtherPage } from "../utils/openFromOtherpAge";
import React from "react";
export function Wiki  () {
  const location = useLocation();

  useEffect(() => {
    const params = new URLSearchParams(location.search);
    const collapseId = params.get('collapseId');
    const tabId = params.get('tab');

    // Handle scroll to collapse section
    if (collapseId) {
      const collapseElement = document.getElementById(collapseId);
      if (collapseElement) {
        const elementTop = collapseElement.getBoundingClientRect().top + window.pageYOffset;
        const offset = window.innerHeight / 2 - collapseElement.offsetHeight / 2;
        const scrollPosition = elementTop - offset;

        window.scrollTo({
          top: scrollPosition,
          behavior: 'smooth',
        });
      }
    }

    // Handle opening the tab
    if (tabId) {
      openFromOtherPage(tabId)({ currentTarget: document.getElementById(tabId)! });
    }
  }, [location.search]);

  return (
       <>
      <div className="row">
        <div className="col">
           <WikiTabs></WikiTabs> 
        </div>
      </div>
      <div className="row">
        <div className="d-flex flex-column justify-content-center align-items-center">
        </div>
      </div>
    </>
  );
}


 export function WikiTabs() {
  const [value, setValue] = React.useState('1');

  const handleChange = (_event: React.SyntheticEvent, newValue: string) => {
    setValue(newValue);
  };

  return (
    <Box sx={{ width: '100%', typography: 'body1' }}>
      <TabContext value={value}>
        <Box sx={{ borderBottom: 1, borderColor: 'divider' }}>
          <TabList onChange={handleChange} aria-label="lab API tabs example">
            <Tab label="About" value="1" />
            <Tab label="Getting started" value="6" />
            <Tab label="Troubleshooting" value="2" />
            <Tab label="Components" value="3" />
            <Tab label="Downloads" value="4" />
            <Tab label="Resources" value="5" />
            
          </TabList>
        </Box>
        <TabPanel value="1">   </TabPanel>
        <TabPanel value="6"> <Started/>  </TabPanel>
        <TabPanel value="2"> <Troubleshooting/> </TabPanel>
        <TabPanel value="3">  </TabPanel>
        <TabPanel value="4">   </TabPanel>
        <TabPanel value="5">  <Sources/> </TabPanel>
      </TabContext>
    </Box>
  );
}

function Started(){

  return(
    <>
    <h3>Differences between React and plain HTML</h3>
    <p>There are some differences in the syntax that can lead to errors.</p>
    <table>
      <tr>
        <th></th>
        <th>Plain HTML</th>
        <th>Using React</th>
      </tr>
      <tr>
        <th> <code>&lt;tags&gt; </code> </th>
        <th> 
          <p> Most tags have to be opened and closed, but some can be only opened. </p> 
          <p> e.g. img, br, ... <code> &lt;img src:"somesource" alt="alt"&gt;  </code> </p>
        </th>
        <th>
          <p> Every tag has to be closed.  </p>
          <p> e.g. img, br, ... 
            <code> &lt;img src:"somesource" alt="alt"/&gt;</code> or 
            <code> &lt;img src:"somesource" alt="alt"&gt; &lt;/img&gt; </code>  </p>
        </th>
      </tr>
      <tr>
        <th>Attribute Names</th>
        <th>
          <p> Global attribute names are always written in lowercase and two words are fused into one by "-". </p>
          <p> E.g. "class", "charset", ...</p>
          <p> This is also the case when using the syle-attribute. </p>
          <p> E.g. <code>style="color:blue; text-align:center"</code></p>
        </th>
        <th> 
          <p>Global attribute names are generally written in lowercase but use the camel case if two words have to be fused. Some attrubutes have slightly different names.</p>
          <p>E.g. "className", "charSet", ...</p>
          <p> This is also the case when using the style-attribute.</p>
          <p> E.g. <code>style=&#123;&#123;vectorEffect: &quot;non-scaling-stroke&quot;&#125;&#125;</code></p>
          <p>This does not apply to the css file!</p>
        </th>
      </tr>
      <tr>
        <th>Style attribute</th>
        <th>
          <p> style="<var>attribute</var>: <var>value</var>; <var>attribute</var>: <var>value</var>" </p>
        </th>
        <th>
          <p> style=&#123;&#123;<var>attribute</var>: "<var>value</var>", <var>attribute</var>: "<var>value</var>" &#125;&#125;</p>
        </th>
      </tr>
    </table>
    </>
  )
}


 function Sources(){
  return(
    <div>
      <Collapsible id="wiki-icons" title="Images and Icons" >
      Most teams need a lot of pictures, components, icons and alike. They can be difficult to find, especially free and open source ones.
      
        <ul>
          <li> <a href="https://bioicons.com/"> https://bioicons.com/</a> </li>
          <li> <a href="https://togotv.dbcls.jp/en/pics.html" > https://togotv.dbcls.jp/en/pics.html </a> </li>
          <li> <a href="https://smart.servier.com/" >https://smart.servier.com/</a> </li>
          <li> <a href="https://openclipart.org/" > https://openclipart.org/</a> </li>
          <li> <a href="https://commons.wikimedia.org/wiki/Category:SVG_files" >https://commons.wikimedia.org/wiki/Category:SVG_files</a> </li>
          <li> <a href="https://www.flaticon.com/">https://www.flaticon.com/</a> </li>
          <li> <a href="https://biologicalicons.com/en">https://biologicalicons.com/en</a> </li>
          <li> <a href="https://www.svgrepo.com/">https://www.svgrepo.com/</a> </li>
          <li> <a href="https://www.humanbiomedia.org/">https://www.humanbiomedia.org/</a> </li>
        </ul>

      </Collapsible>
      <Collapsible id="wiki-colors" title="Colours" >
        Need a slightly lighter version of one of your colors or a mix of two colours? 
        <ul>
          <li><a href="https://www.w3schools.com/colors/colors_mixer.asp"> https://www.w3schools.com/colors/colors_mixer.asp</a></li>
        </ul>
      </Collapsible>
      <Collapsible id="wiki-tools" title="Coding Tools">
        Generators
        <ul>
          <li><a href="https://www.cssportal.com/">https://www.cssportal.com/</a></li>
          <li><a href="https://htmlcss.tools/">https://htmlcss.tools/</a></li>
        </ul>
      </Collapsible>

      <Collapsible id="wiki-placeholder" title="Placeholders">
        <ul>
          <li><a href="https://www.loremipsum.de/">https://www.loremipsum.de/</a></li>
        </ul>
      </Collapsible>

      <Collapsible id="wiki-svgs" title="SVGs">
        <ul>
          <li><a href="https://superdesigner.co/tools/svg-backgrounds">https://superdesigner.co/tools/svg-backgrounds</a></li>
        </ul>
      </Collapsible>

      <Collapsible id="wiki-accessibility" title="Accessibility">
      <ul>
        <li><a href="https://schema.org">https://schema.org</a></li>
      </ul>
      </Collapsible>
    </div>

  )
} 



import { WikiSelector } from "../components/Filter";
import { Code } from "../components/code";
function Troubleshooting(){
  
  return(
    <div>
      Please select what you want to troubleshoot for. 
      <WikiSelector></WikiSelector>
      <div id="nono" className="noshow">
        This combination returns no instances. 
      </div>
       <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-1" title="Argument of type X is not assignable to parameter of type Y. ">
        <h6>Example</h6>
        <h6>Solutions</h6>
       
        </Collapsible>
      </div>
      <div className="filterable all react type"> 
        <Collapsible id="wiki-trouble-2" title="Type X is not assignable to type Y.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all css"> 
        <Collapsible id="wiki-trouble-3" title="I added css styles but they do not show">
        <h6>Example</h6>
        <p>The color is not showing on hover.</p>
        <Code>.nav-link:hover &#123;
          color: var(--darkpurple);
          background-color: var(--yellow) !important;
          border-radius: 3px;
          &#125;</Code>
        <h6>Solution</h6>
        <p>Styles not showing is often a case of a different style overriding your style. Some styles are pre defined by bootstrap or other packages you may use. </p>
        <p> If an external package is overriding your style, you need to add the <b>!important</b> tag to your style. </p>
        <p> If one of your own styles is overriding the new style, you can change your old style or define a new, more specific style case. E.g. by using a more specific css path. But you may still need to add the <b>!important</b> tag. </p>
        <Code> .nav-link:hover &#123;
          color: var(--darkpurple) <b>!important</b>;
          background-color: var(--yellow) !important;
          border-radius: 3px;
          &#125;
          </Code>
        </Collapsible>
      </div>
      <div className="filterable all  react type property">
        <Collapsible id="wiki-trouble-4" title="Property x is missing in type y but required in type z.">
        <h6>Example</h6>
        <p className="problem-error"> Argument of type '&#123; [x: string]: any; &#125;' is not assignable to parameter of type '&#123; classNames: string[]; &#125;'.
        Property 'classNames' is missing in type '&#123; [x: string]: any; &#125;' but required in type '&#123; classNames: string[]; &#125;'.</p>
        <p> for </p>
        <Code>className=&#123;joinClassNames(&#123;[&#39;text-event&#39;, className]&#125;)&#125; </Code>
        <h6>Solutions</h6>
        <p>In this example, the problem was that the property "classNames" was not explicitly named.</p>
        <p>Changing it to </p>
          <Code>className=&#123;joinClassNames(&#123;<b>classNames:</b>[&#39;text-event &#39;, className]&#125;)&#125;</Code>
        </Collapsible>
      </div>
      <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-5" title="Property x does not exist on type Y.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all react type property">
        <Collapsible id="wiki-trouble-6" title="Type X is missing the following properties from type Y: a, b, c">
        <h6>Example</h6>
        <p className="problem-error">
        Type '&#123; date: string; text: string; &#125;' is missing the following properties from type 'TextEventProps': marker, card
        </p>
        <p>In reference of the interface TextEventProps:</p>
        <Code>
        <p>interface TextEventProps &#123; </p>
        <p>date: string; </p>
        <p>text: string; </p>
        <p>marker: React.ReactNode; </p>
        <p>id: string; </p>
        <p>card: Function; </p>
        &#125;
        </Code>
        <p>For the code:</p>
        <Code>
          <p> &lt;TextEvent </p>
          <p> id="05"</p>
          <p> date="14-06-2024"</p>
          <p> text="Test test"</p>
          <p> /&gt;</p>
        </Code>
        <h6>Solutions</h6>
        <p>One solution could be getting rid of the properties you do not need everywhere and create new property interfaces for all cases.</p>
        <p>If you want to stick to more general Interfaces, you can make properties optional:</p>
        <Code>
        <p>interface TextEventProps &#123; </p>
        <p>date: string; </p>
        <p>text: string; </p>
        <p>marker?: React.ReactNode; </p>
        <p>id: string; </p>
        <p>card?: Function; </p>
        &#125;
        </Code>
        <p>Remember that this can lead to different return cases for your functions.</p>
        </Collapsible>
      </div>
      <div className="filterable all react type">
        <Collapsible id="wiki-trouble-7" title="Type 'x | undefined' is not assignable to type 'x'.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all pipeline">
        <Collapsible id="wiki-trouble-8" title="The pipeline passed but the Wiki is not visible under the url">
        <p>This error could be a result of a wrong base url in the vite.config.js file.</p>
        <p>E.g. if you switched from plain HTML to the react framework. </p>
        <h6>Example</h6>
        <Code>
          <p>return defineConfig(&#123;</p>
          <p>base: `/`,</p>
          <p>...</p>
        </Code>
        <h6>Solution</h6>
        <p>Change the base url to reflect the correct team url.</p>
        <Code>
          <p>return defineConfig(&#123;</p>
          <p>base: `/$&#123;stringToSlug(env.VITE_TEAM_NAME)&#125;/`,</p>
          <p>...</p>
        </Code>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-9" title="NS_ERROR_CORRUPTED_CONTENT error in console">
        <p> &rarr; See also "The pipeline passed but the Wiki is not visible under the url" as these errors can be connected.</p>
        <p> This error for css and js files can be the result of wrong <b>rollupOptions</b> in for the build, to be specific wrong <b>output</b> and <b>assetFileNames</b> options and possibly wrong/empty <b>css</b> options in your vite.config.js. </p>
        <h6>Example</h6>
        <p>In our case, we had the following code on our vite.config.js</p>
        <Code>
        <p>build: &#123; </p>
      <p>outDir: "dist",</p>
      <p>rollupOptions: &#123;</p>
        <p>output: &#123;</p>
          <p> assetFileNames: `assets/[ext]/[name]-[hash].[ext]`</p>
        <p>&#125; &#125; &#125; , </p>
        </Code>
        <p> Our <b>css</b> options were empty, which could also have played a factor for the css files.</p>
        <Code>
        <p>css: &#123;</p>
      <p>preprocessorOptions: &#123;</p>
        <p>css: &#123;</p>
          <p>  //javascriptEnabled: true, // Enable JavaScript in CSS (useful for certain CSS preprocessor plugins)</p>
       <p> &#125; &#125; &#125;,</p>  
        </Code>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-10" title="Blocked due to MIME type (“text/html”) mismatch (X-Content-Type-Options: nosniff) (Firefox)">
        <p> &rarr; See also "Refused to apply style from &lt;&lt;css file&gt;&gt; because its MIME type ('text/html') is not a supported stylesheet MIME type, strict MIME checking is enabled (Edge)"</p>
        <p>This error could </p>
        </Collapsible>
      </div>
      <div className="filterable all console">
        <Collapsible id="wiki-trouble-11" title="Refused to apply style from <<css file>> because its MIME type ('text/html') is not a supported stylesheet MIME type, strict MIME checking is enabled (Edge)">
        <p> &rarr; See also "Blocked due to MIME type (“text/html”) mismatch (X-Content-Type-Options: nosniff) (Firefox)"</p>
        <p>This error could </p>
        </Collapsible>
      </div>
      <div className="filterable all react type">
        <Collapsible id="wiki-trouble-12" title="Type 'undefined' cannot be used as an index type">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div>
      <div className="filterable all react overload">
        <Collapsible id="wiki-trouble-13" title="No overload matches this call.">
        <h6>Example</h6>
        <h6>Solutions</h6>
        </Collapsible>
      </div> 
      <div className="filterable all react module">
        <Collapsible id="wiki-trouble-14" title="Module Z has already exported a member named A. Consider explicitly re-exporting to resolve the ambiguity.">
        <h6>Example</h6>
        index.tsx: 
        <p className="problem-error"> Module "./Bfh.tsx" has already exported a member named 'LabTabs'. Consider explicitly re-exporting to resolve the ambiguity.</p>
        <h6>Solutions</h6>
        Simply rename the function in one of the modules or consider making it a component if you plan on using it frequently.  
        </Collapsible>
      </div>
      <div className="filterable all pipeline">
        <Collapsible id="wiki-trouble-15" title="error TS6133: 'event' is declared but its value is never read.">
          <h6>Example</h6>
          HorizontalTimeline.tsx: 
          <div className="terminal-box">
            $ yarn build
            <p>yarn run v1.22.19</p>
            <p>$ tsc && vite build</p>
            <p className="terminal-error">src/components/HorizontalTimeline.tsx(67,23): error TS6133: 'event' is declared but its value is never read.
            error Command failed with exit code 2.</p>
            <p>info Visit https://yarnpkg.com/en/docs/cli/run for documentation about this command.</p>
            </div>
          <p>in</p>
          <Code>
          const openPop =  (event : React.MouseEvent&lt;HTMLButtonElement, MouseEvent&gt;) =&gt; {}
          </Code>
          <h6>Solutions</h6>
          <p>Change to: </p>
          <Code>
          const openPop =  (_event : React.MouseEvent&lt;HTMLButtonElement, MouseEvent&gt;) =&gt; {}
          </Code>
        </Collapsible>
      </div>
    </div>
  )
} 


